# Python Intelligent Agent Framework (piaf)

![pipeline status](https://gitlab.com/ornythorinque/piaf/badges/master/pipeline.svg)
![coverage report](https://gitlab.com/ornythorinque/piaf/badges/master/coverage.svg?job=test)


The aim of piaf is to provide a FIPA-compliant agent framework using Python. It uses **asyncio** to power agents.

**For now, this work is experimental and subject to changes.**

## Documentation
The full documentation (both user and API) is available here: https://ornythorinque.gitlab.io/piaf
It will teach you how to install and run your own agents.

## Author(s)
* ornythorinque (pierredubaillay@outlook.fr)
